# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: dropsonde/pb/error.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='dropsonde/pb/error.proto',
  package='events',
  syntax='proto2',
  serialized_pb=_b('\n\x18\x64ropsonde/pb/error.proto\x12\x06\x65vents\"6\n\x05\x45rror\x12\x0e\n\x06source\x18\x01 \x02(\t\x12\x0c\n\x04\x63ode\x18\x02 \x02(\x05\x12\x0f\n\x07message\x18\x03 \x02(\tB1\n!org.cloudfoundry.dropsonde.eventsB\x0c\x45rrorFactory')
)




_ERROR = _descriptor.Descriptor(
  name='Error',
  full_name='events.Error',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='source', full_name='events.Error.source', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='code', full_name='events.Error.code', index=1,
      number=2, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='message', full_name='events.Error.message', index=2,
      number=3, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=36,
  serialized_end=90,
)

DESCRIPTOR.message_types_by_name['Error'] = _ERROR
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Error = _reflection.GeneratedProtocolMessageType('Error', (_message.Message,), dict(
  DESCRIPTOR = _ERROR,
  __module__ = 'dropsonde.pb.error_pb2'
  # @@protoc_insertion_point(class_scope:events.Error)
  ))
_sym_db.RegisterMessage(Error)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('\n!org.cloudfoundry.dropsonde.eventsB\014ErrorFactory'))
# @@protoc_insertion_point(module_scope)



import os
import re
import sys
import six
import pkgutil
import traceback
import importlib
from .__version__ import __version__


def list_modules(package):
    for importer, modname, ispkg in pkgutil.iter_modules(package.__path__):
        yield importlib.import_module('.' + modname, package.__name__)


def get_last_name(mod):
    name = mod.__name__.split('.')[-1]
    if name.endswith('_pb2'):
        name = re.sub('_pb2$', '', name)
    return name


def load_modules():
    try:
        from . import pb

        _self = sys.modules[__name__]
        full_name = '.'.join([__name__, 'pb'])
        setattr(_self, 'pb', pb)
        sys.modules[full_name] = pb
        for module in list_modules(pb):
            name = get_last_name(module)
            setattr(_self, name, module)
            if not hasattr(pb, name):
                setattr(pb, name, module)
            full_name = '.'.join([__name__, name])
            if full_name in sys.modules:
                raise KeyError('Module "{0}" is already set'.format(full_name))
            sys.modules[full_name] = module

    except Exception:
        traceback.print_exc()
        raise


try:
    import google.protobuf
    load_modules()
except ImportError:
    print('dropsonde: Unable to import protobuf. Assuming installing...')
    pass



def get_uuid_string(**x):
    """This method parses a UUID protobuf message type from its component
    'high' and 'low' longs into a standard formatted UUID string

    Args:
        x (dict): containing keys, 'low' and 'high' corresponding to the UUID
            protobuf message type

    Returns:
        str: UUID formatted string
    """
    if 'low' not in x or 'high' not in x:
        return None

    # convert components to hex strings and strip off '0x'
    low = int(x['low'])
    high = int(x['high'])

    l = hex(low)[2:-1]
    h = hex(high)[2:-1]

    # ensure we have leading 0 bytes set
    l = ''.join(['0' * (16 - len(l)), l])
    h = ''.join(['0' * (16 - len(h)), h])

    # split/reverse/join little endian bytes
    x = ''.join([
        ''.join([l[i:i+2] for i in range(0, len(l), 2)][::-1]),
        ''.join([h[i:i+2] for i in range(0, len(h), 2)][::-1]),
    ])

    # create uuid formatted string
    return '-'.join([x[:8], x[8:12], x[12:16], x[16:20], x[20:]])



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: dropsonde/pb/log.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='dropsonde/pb/log.proto',
  package='events',
  syntax='proto2',
  serialized_pb=_b('\n\x16\x64ropsonde/pb/log.proto\x12\x06\x65vents\"\xc5\x01\n\nLogMessage\x12\x0f\n\x07message\x18\x01 \x02(\x0c\x12\x34\n\x0cmessage_type\x18\x02 \x02(\x0e\x32\x1e.events.LogMessage.MessageType\x12\x11\n\ttimestamp\x18\x03 \x02(\x03\x12\x0e\n\x06\x61pp_id\x18\x04 \x01(\t\x12\x13\n\x0bsource_type\x18\x05 \x01(\t\x12\x17\n\x0fsource_instance\x18\x06 \x01(\t\"\x1f\n\x0bMessageType\x12\x07\n\x03OUT\x10\x01\x12\x07\n\x03\x45RR\x10\x02\x42/\n!org.cloudfoundry.dropsonde.eventsB\nLogFactory')
)



_LOGMESSAGE_MESSAGETYPE = _descriptor.EnumDescriptor(
  name='MessageType',
  full_name='events.LogMessage.MessageType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='OUT', index=0, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ERR', index=1, number=2,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=201,
  serialized_end=232,
)
_sym_db.RegisterEnumDescriptor(_LOGMESSAGE_MESSAGETYPE)


_LOGMESSAGE = _descriptor.Descriptor(
  name='LogMessage',
  full_name='events.LogMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='message', full_name='events.LogMessage.message', index=0,
      number=1, type=12, cpp_type=9, label=2,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='message_type', full_name='events.LogMessage.message_type', index=1,
      number=2, type=14, cpp_type=8, label=2,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='events.LogMessage.timestamp', index=2,
      number=3, type=3, cpp_type=2, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='app_id', full_name='events.LogMessage.app_id', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='source_type', full_name='events.LogMessage.source_type', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='source_instance', full_name='events.LogMessage.source_instance', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _LOGMESSAGE_MESSAGETYPE,
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=35,
  serialized_end=232,
)

_LOGMESSAGE.fields_by_name['message_type'].enum_type = _LOGMESSAGE_MESSAGETYPE
_LOGMESSAGE_MESSAGETYPE.containing_type = _LOGMESSAGE
DESCRIPTOR.message_types_by_name['LogMessage'] = _LOGMESSAGE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

LogMessage = _reflection.GeneratedProtocolMessageType('LogMessage', (_message.Message,), dict(
  DESCRIPTOR = _LOGMESSAGE,
  __module__ = 'dropsonde.pb.log_pb2'
  # @@protoc_insertion_point(class_scope:events.LogMessage)
  ))
_sym_db.RegisterMessage(LogMessage)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('\n!org.cloudfoundry.dropsonde.eventsB\nLogFactory'))
# @@protoc_insertion_point(module_scope)
